summaryrefslogtreecommitdiffstats
path: root/kalarm/lib/timespinbox.h
diff options
context:
space:
mode:
Diffstat (limited to 'kalarm/lib/timespinbox.h')
-rw-r--r--kalarm/lib/timespinbox.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/kalarm/lib/timespinbox.h b/kalarm/lib/timespinbox.h
index 901c97e2..4bacd494 100644
--- a/kalarm/lib/timespinbox.h
+++ b/kalarm/lib/timespinbox.h
@@ -45,21 +45,22 @@
class TimeSpinBox : public SpinBox2
{
Q_OBJECT
+ TQ_OBJECT
public:
/** Constructor for a wrapping time spin box which can be used to enter a time of day.
* @param use24hour True for entry of 24-hour clock times (range 00:00 to 23:59).
* False for entry of 12-hour clock times (range 12:00 to 11:59).
* @param parent The parent object of this widget.
* @param name The name of this widget.
*/
- explicit TimeSpinBox(bool use24hour, TQWidget* parent = 0, const char* name = 0);
+ explicit TimeSpinBox(bool use24hour, TQWidget* tqparent = 0, const char* name = 0);
/** Constructor for a non-wrapping time spin box which can be used to enter a length of time.
* @param minMinute The minimum value which the spin box can hold, in minutes.
* @param maxMinute The maximum value which the spin box can hold, in minutes.
* @param parent The parent object of this widget.
* @param name The name of this widget.
*/
- TimeSpinBox(int minMinute, int maxMinute, TQWidget* parent = 0, const char* name = 0);
+ TimeSpinBox(int minMinute, int maxMinute, TQWidget* tqparent = 0, const char* name = 0);
/** Returns true if the spin box holds a valid value.
* An invalid value is displayed as asterisks.
*/
@@ -45,21 +45,22 @@
* @param use24hour True for entry of 24-hour clock times (range 00:00 to 23:59).
* False for entry of 12-hour clock times (range 12:00 to 11:59).
- * @param parent The parent object of this widget.
+ * @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/
@@ -45,21 +45,22 @@
* @param minMinute The minimum value which the spin box can hold, in minutes.
* @param maxMinute The maximum value which the spin box can hold, in minutes.
- * @param parent The parent object of this widget.
+ * @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/